"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from ..shared import couponobject as shared_couponobject
from dataclasses_json import Undefined, dataclass_json
from sdk import utils


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class Coupons:
    r"""Successful response"""
    
    coupons: list[shared_couponobject.CouponObject] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('coupons') }})  
    